@@ -47,7 +47,7 @@ class URI(object):
     You can write the protocol in lowercase if you like (``pyro:...``) but it will
     automatically be converted to uppercase internally.
     """
-    uriRegEx = re.compile(r"(?P<protocol>[Pp][Yy][Rr][Oo][a-zA-Z]*):(?P<object>\S+?)(@(?P<location>\S+))?$")
+    uriRegEx = re.compile(r"(?P<protocol>[Pp][Yy][Rr][Oo][a-zA-Z]*):(?P<object>\S+?)(@(?P<location>.+))?$")
 
     def __init__(self, uri):
         if isinstance(uri, URI):
@@ -663,7 +663,9 @@ class Proxy(object):
 
     def _pyroAsync(self, asynchronous=True):
         """turns the proxy into asynchronous mode so you can do asynchronous method calls,
-        or sets it back to normal sync mode if you set asynchronous=False."""
+        or sets it back to normal sync mode if you set asynchronous=False.
+        This setting is strictly on a per-proxy basis (unless an exact clone is made
+        via copy.copy)."""
         self.__async = asynchronous
 
     if sys.version_info < (3, 7):
