@@ -929,7 +929,7 @@ def get_exposed_members(obj, only_exposed=True, as_lists=False, use_cache=True):
         if is_private_attribute(m):
             continue
         v = getattr(obj, m)
-        if inspect.ismethod(v) or inspect.isfunction(v):
+        if inspect.ismethod(v) or inspect.isfunction(v) or inspect.ismethoddescriptor(v):
             if getattr(v, "_pyroExposed", not only_exposed):
                 methods.add(m)
                 # check if the method is marked with the 'oneway' decorator:
@@ -987,7 +987,8 @@ def set_exposed_property_value(obj, propname, value, only_exposed=True):
 
 
 _private_dunder_methods = frozenset([
-    "__init__", "__call__", "__new__", "__del__", "__repr__", "__unicode__",
+    "__init__", "__init_subclass__", "__class__", "__module__", "__weakref__",
+    "__call__", "__new__", "__del__", "__repr__", "__unicode__",
     "__str__", "__format__", "__nonzero__", "__bool__", "__coerce__",
     "__cmp__", "__eq__", "__ne__", "__hash__", "__ge__", "__gt__", "__le__", "__lt__",
     "__dir__", "__enter__", "__exit__", "__copy__", "__deepcopy__", "__sizeof__",
